[🦁 Brave Search Python Client](https://helmuthva.gitbook.io/brave-search-api-client)

## [0.1.8](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/compare/v0.1.7..v0.1.8) - 2025-01-02

### 📚 Documentation

- *(sphinx)* Generate docs with sphinx, start with rtd - ([137d457](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/commit/137d45758fba56e7ff4f4fe637ac92e4726c0a12))
- *(sphinx,readthedocs)* Introduce - ([a35f79d](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/commit/a35f79d692d39a9df219274f8433bcf6ef53b713))


## [0.1.7](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/compare/v0.1.6..v0.1.7) - 2025-01-01

### 📚 Documentation

- *(keywords)* Add common synonyms - ([56af4ef](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/commit/56af4ef404d1589feafc5feef43207653fddbdad))


## [0.1.6](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/compare/v0.1.5..v0.1.6) - 2025-01-01

### 📚 Documentation

- *(readme)* Polish - ([8b92c6f](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/commit/8b92c6f4e52362ee9504e4f8d2845c5eea4a2c2c))


## [0.1.5](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/compare/v0.1.4..v0.1.5) - 2025-01-01

### 🐛 Bug Fixes

- *(client)* Mock data loading when imported - ([644c21f](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/commit/644c21f1eb05a95eeb1c93b5c138c8eef91a769a))


## [0.1.4](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/compare/v0.1.3..v0.1.4) - 2025-01-01

### 🐛 Bug Fixes

- *(client)* Mock data loading when imported - ([8d4cc14](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/commit/8d4cc14091144345a02c1ed2a499d43c5af45b61))


## [0.1.3](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/compare/v0.1.2..v0.1.3) - 2025-01-01

### 🐛 Bug Fixes

- *(client)* Mock data loading when imported - ([c215ec2](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/commit/c215ec2ec75b1c3616fcd33f445601b4d27ede8e))


## [0.1.2](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/compare/v0.1.1..v0.1.2) - 2025-01-01

### ⛰️  Features

- *(client)* Add BraveSearch.is_connnected, enabling to check if the API is reachable - ([c7ba46c](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/commit/c7ba46cb65557a2ac22bbc5be668e7adfa216252))


## [0.1.1](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/compare/v0.1.0..v0.1.1) - 2025-01-01

### ⛰️  Features

- *(mocking)* If API Key is set to brave_search_python_client.MOCK_API_KEY the search methods return mock data. Useful for integration testing - ([b5a34d7](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/commit/b5a34d74bfd754c24af2220f2eec1354a1e8c19d))

### 🚜 Refactor

- *(codesmell)* Repeated use of strings in tests - ([f7f8622](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/commit/f7f862223e4e638757210930fcce45d3d3353442))


## [0.0.12](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/compare/v0.0.11..v0.0.12) - 2025-01-01

### 🚜 Refactor

- *(codesmell)* Repeated use of strings in tests - ([9238dc0](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/commit/9238dc0275030a9edc2875afe4f7d20ca890a467))


## [0.0.11](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/compare/v0.0.10..v0.0.11) - 2025-01-01

### 📚 Documentation

- *(media)* Absolute links for PyPI - ([be729f4](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/commit/be729f4c6a808ba8134189ad54f7d834959ca222))


## [0.0.10](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/compare/v0.0.9..v0.0.10) - 2025-01-01

### 📚 Documentation

- *(readme)* Add media - ([2299600](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/commit/2299600dc222bab31902b5623cbb69c351f5cac4))

### ⚙️ Miscellaneous Tasks

- *(streamlit)* Must not be an extra to be hosted on community cloud - ([18e665d](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/commit/18e665da5d2b6ff2f34ffc1d299c68fad671246d))


## [0.0.9](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/compare/v0.0.8..v0.0.9) - 2025-01-01

### 📚 Documentation

- *(readme)* Start to polish - ([6a05049](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/commit/6a05049dd2b983af219c44f9109fb92e03b12bd4))


## [0.0.8](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/compare/v0.0.7..v0.0.8) - 2025-01-01

### ⛰️  Features

- *(examples)* Jupyter Notebook and simple Python script - ([bacc4df](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/commit/bacc4df794992b0174ccc3ba8fac900dcadfbd42))


## [0.0.7](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/compare/v0.0.6..v0.0.7) - 2025-01-01

### ⛰️  Features

- *(example)* Streamlit app - ([833f255](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/commit/833f255fcdd8591db4e5ae58dd254cd9c1c5c955))


## [0.0.6](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/compare/v0.0.5..v0.0.6) - 2025-01-01

### 🚜 Refactor

- *(client)* Use request objects; enh(validation): now complete; chore(devcontainer): include - ([4410559](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/commit/4410559cee42894c323d7f46234d4d3310f627fb))

### 📚 Documentation

- Polish - ([7afc490](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/commit/7afc4901f156daadcd4bfba206811858772d1458))


## [0.0.5](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/compare/v0.0.4..v0.0.5) - 2025-01-01

### ⚙️ Miscellaneous Tasks

- *(github)* Adapt to renamed command - ([211bb41](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/commit/211bb4138b38bb730d3e0a612617ade24cc7f6f8))


## [0.0.4](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/compare/v0.0.3..v0.0.4) - 2025-01-01

### 📚 Documentation

- Basic documentation - ([9384f79](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/commit/9384f799ba2da1fe56f90157a901bd5f9bcff054))
- Polish - ([bb1909f](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/commit/bb1909fc8ac0b5d945aa5e62724d710d0f516f83))

### ⚙️ Miscellaneous Tasks

- *(github)* We don't need node in this project - ([5cfd679](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/commit/5cfd679d75d4e1a939b8210aa4a5785cf6587894))


## [0.0.3](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/compare/v0.0.2..v0.0.3) - 2024-12-31

### 📚 Documentation

- *(docker)* Fix image name in readme and contributing - ([27e6367](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/commit/27e63677561160fd35eb38b04196acdcbfc55590))


## [0.0.2](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/compare/v0.0.1..v0.0.2) - 2024-12-31

### 📚 Documentation

- *(gitbook)* Introduce gitbook site - ([f574b41](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/commit/f574b41d40218915de3ff5095c41f3f6ffb6b04d))

### 🎨 Styling

- Remove superfluous pass - ([8726a6b](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/commit/8726a6bd15a58cdcfc18105ccb2247157b870c16))


## [0.0.1] - 2024-12-31

### 📚 Documentation

- *(readme)* Tweak - ([345ea07](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/commit/345ea07ffcae7ab30717954eb00a70b1c4045dc7))

### ⚙️ Miscellaneous Tasks

- *(github)* Secret api key for e2e test, and baseline to check on secrets in code - ([5593b2b](https://github.com/helmut-hoffer-von-ankershoffen/brave-search-python-client/commit/5593b2b6975703797476d28731788e5d7e9e40e9))

## New Contributors ❤️

* @helmut-hoffer-von-ankershoffen made their first contribution

<!-- built with love in Berlin by Helmut Hoffer von Ankershoffen -->
